@@ -3,14 +3,27 @@
 /**                                                                         **/
 /**  Antenna Visualization Toolkit                                          **/
 /**                                                                         **/
-/**  Adrian Agogino  agogino@ece.utexas.edu                                 **/
-/**  Ken Harker      kharker@cs.utexas.edu                                  **/
-/**                                                                         **/
-/**  May 1998                                                               **/
+/**  Copyright (C) 1998 Adrian Agogino, Ken Harker                          **/
+/**  Copyright (C) 2005 Joop Stakenborg                                     **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 #include <assert.h>
 #include <stddef.h>
@@ -336,7 +349,6 @@ void DrawRFPowerDensitySurface(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -473,7 +485,6 @@ void DrawPolarizationSenseSurface(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -647,7 +658,6 @@ void DrawPolarizationTiltSurface(Ant *antData) {
   int      latitude;        /**  Loop counter         **/
   int      longitude;       /**  Loop counter         **/
   int      i;               /**  Loop counter         **/
-  int      n;               /**  Loop counter         **/
   double   tx;              /**  Temporary x          **/
   double   ty;              /**  Temporary y          **/
   double   tz;              /**  Temporary z          **/
@@ -780,7 +790,6 @@ void DrawAxialRatioSurface(Ant *antData) {
   int      latitude;        /**  Loop counter         **/
   int      longitude;       /**  Loop counter         **/
   int      i;               /**  Loop counter         **/
-  int      n;               /**  Loop counter         **/
   double   tx;              /**  Temporary x          **/
   double   ty;              /**  Temporary y          **/
   double   tz;              /**  Temporary z          **/
@@ -902,7 +911,7 @@ void DrawAxialRatioSurface(Ant *antData) {
 /**                                                                         **/
 /**  This function traverses each of the points and draws it on the screen  **/
 /**  as a triangular mesh rendered smooth shaded.  Each control point is    **/
-/**  colored only if it is in a NULL
+/**  colored only if it is in a NULL                                        **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
@@ -916,7 +925,6 @@ void DrawShowNullsSurface(Ant *antData) {
   int      latitude;        /**  Loop counter         **/
   int      longitude;       /**  Loop counter         **/
   int      i;               /**  Loop counter         **/
-  int      n;               /**  Loop counter         **/
   double   tx;              /**  Temporary x          **/
   double   ty;              /**  Temporary y          **/
   double   tz;              /**  Temporary z          **/
@@ -1059,7 +1067,6 @@ void DrawRFPowerDensitySphere(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -1163,7 +1170,6 @@ void DrawPolarizationSenseSphere(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -1328,7 +1334,6 @@ void DrawPolarizationTiltSphere(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -1454,7 +1459,6 @@ void DrawAxialRatioSphere(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
@@ -1584,7 +1588,6 @@ void DrawShowNullsSphere(Ant *antData) {
   int      latitude;         /**  Loop counter     **/
   int      longitude;        /**  Loop counter     **/
   int      i;                /**  Loop counter     **/
-  int      n;                /**  Loop counter     **/
   double   tx;               /**  Temporary x      **/
   double   ty;               /**  Temporary y      **/
   double   tz;               /**  Temporary z      **/
