@@ -3,18 +3,33 @@
 /**                                                                         **/
 /**  Antenna Visualization Toolkit                                          **/
 /**                                                                         **/
-/**  Adrian Agogino  agogino@ece.utexas.edu                                 **/
-/**  Ken Harker      kharker@cs.utexas.edu                                  **/
-/**                                                                         **/
-/**  May 1998                                                               **/
+/**  Copyright (C) 1998 Adrian Agogino, Ken Harker                          **/
+/**  Copyright (C) 2005 Joop Stakenborg                                     **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <math.h>
+#define __USE_XOPEN_EXTENDED
+#include <string.h>
 #include "ant.h"
 #include "pcard.h"
 
@@ -271,13 +286,12 @@ void PrintTubeOffset(FILE *f,
 /*****************************************************************************/
 
 
-void WriteCardFile(char *file_name, Ant *the_ant, int step_size, double freq) {
+void WriteCardFile(CONST84 char *file_name, Ant *the_ant, int step_size, double freq) {
 
   FILE *fout;            /**  Output file                 **/
   char *card;            /**  Ouput buffer                **/
   Tube *the_tube;        /**  Current tube                **/
   int   i;               /**  Loop counter                **/
-  int   j;               /**  Loop counter                **/
   int   curr_tube;       /**  Current tube                **/
   int   increment;       /**  Increment in theta and phi  **/
   bool  seen_rp;         /**  Seen the RP card            **/
@@ -331,13 +345,12 @@ void WriteCardFile(char *file_name, Ant *the_ant, int step_size, double freq) {
 /*****************************************************************************/
 
 
-void WriteMultAntsFile(char *file_name, int step_size, double freq) {
+void WriteMultAntsFile(CONST84 char *file_name, int step_size, double freq) {
 
   FILE *fout;            /**  Output file                 **/
   char *card;            /**  Ouput buffer                **/
   Tube *the_tube;        /**  Current tube                **/
   int   i;               /**  Loop counter                **/
-  int   j;               /**  Loop counter                **/
   int   k;               /**  Loop counter                **/
   int   tag;             /**  Tag number                  **/
   int   curr_tube;       /**  Current tube                **/
@@ -431,69 +444,6 @@ void WriteMultAntsFile(char *file_name, int step_size, double freq) {
 }  /**  End of WriteMultAntFile  **/
 
 
-/*****************************************************************************/
-/*****************************************************************************/
-/**                                                                         **/
-/**                         WriteVolumeCardFile                             **/
-/**                                                                         **/
-/*****************************************************************************/
-/*****************************************************************************/
-
-
-void WriteVolumeCardFile(char *file_name, 
-                          Ant *the_ant, 
-                          int  step_size, 
-                       double  freq) {
-
-  FILE *fout;       /**  Output file                 **/
-  char *card;       /**  Ouput buffer                **/
-  Tube *the_tube;   /**  Current tube                **/
-  int   i;          /**  Loop counter                **/
-  int   j;          /**  Loop counter                **/
-  int   curr_tube;  /**  Current tube                **/
-  int   increment;  /**  Increment in theta and phi  **/
-  bool  seen_rp;    /**  Seen the RP card            **/
-  bool  finished_tubes;
-
-  finished_tubes = false;
-  curr_tube = 1;
-  fout = fopen(file_name, "wt");
-  seen_rp = false;
-
-  if(fout == NULL)
-    fprintf(stderr, "Could not open file %s for writing\n", file_name);
-  else {
-    the_tube = the_ant->first_tube;
-    for(i=0; i < the_ant->card_count; i++) {
-      card = the_ant->cards[i];
-      if((card[0] == 'G') && (card[1] == 'W')) {
-        while((the_tube != NULL) && (!finished_tubes)) {
-          PrintTube(fout, the_tube, curr_tube++);
-          the_tube = the_tube->next;
-        }
-        finished_tubes = true;
-      } else if ((card[0] == 'R') && (card[1] == 'P')) {
-        if (seen_rp == false) {
-          increment = 361 / step_size;
-          fprintf(fout,"RP  0   %d   %d    1001   0   0   %d   %d     0   0\n",
-            increment, increment, step_size, step_size);
-            seen_rp = true;
-        } else {
-        }  /**  Have we already output RP?  **/
-      } else if ((card[0] == 'F') && (card[1] == 'R')) {
-        fprintf(fout,"FR  0    %d    0   0   %f     1.000     .0000     .0000    .0000    .0000\n", FreqSteps, freq);
-      } else if ((card[0] == 'G') && (card[1] == 'N')) {
-        /**  Do nothing  **/
-      } else {
-        fprintf(fout, "%s", card);
-      }  /**  Just output all other lines  **/
-    }  /**  For each card  **/ 
-    fclose(fout);
-  }  /**  Antenna exists in memory  **/
-
-}  /**  End of WriteVolumeCardFile  **/
-
-
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
@@ -544,15 +494,13 @@ bool CardToTube(char *card, Tube *tube) {
 /*****************************************************************************/
 
 
-void ReadCardFile(char *file_name, Ant *antData) {
+void ReadCardFile(CONST84 char *file_name, Ant *antData) {
 
   FILE   *fin;          /**  Input file             **/
   char    line[256];    /**  Input buffer           **/
-  char    buf[256];     /**  For comment help       **/
   Tube    new_tube;     /**  Current tube           **/
   char   *result;       /**  Result of operation    **/
   bool    seen_ground;  /**  Seen a ground yet      **/
-  int     MHz;          /**  Frequency in MHz       **/
   int     dummy;        /**  Fields we ignore       **/
   double  max_x;        /**  Dynamic range of X     **/
   double  max_y;        /**  Dynamic range of Y     **/
@@ -606,7 +554,7 @@ void ReadCardFile(char *file_name, Ant *antData) {
 
       if((line[0] == 'F') && (line[1] == 'R')) {
         sscanf(line+2, "%d%d%d%d%lf%d%d%d%d", &dummy, &dummy, &dummy, &dummy, 
-          &antData->frequency, &dummy, &dummy, &dummy, &dummy, &dummy);
+          &antData->frequency, &dummy, &dummy, &dummy, &dummy);
 	/*
         antData->ground_specified = false;        
 	*/
@@ -694,8 +642,6 @@ void ParseFieldData(FILE *fin,
   char        *ptr;              /**  Pointer                            **/
   FieldVal     val;              /**  Value of the radiation             **/
   char         sense[10];        /**  Buffer                             **/
-  char         c;                /**  Individual char                    **/
-  char         d;                /**  Individual char                    **/
   int          count;            /**  Running count                      **/
   int          max_data;         /**  Data limit                         **/
   int          i;                /**  Loop counter                       **/
@@ -705,7 +651,6 @@ void ParseFieldData(FILE *fin,
   int          seg_num;          /**  Segment number                     **/
   int          tag_num;          /**  Wire tag                           **/
   int          card_num;         /**  Current card number                **/
-  int          dummyi;           /**  Data we don't care about           **/
   double       dummyf;           /**  Data we don't care about           **/
   double       mag;              /**  Magnitude of the current           **/
   double       phase;            /**  Phase of the current               **/
@@ -900,15 +845,11 @@ void GetNextPattern(FILE *fin, FieldData *field_data) {
   char        *ptr;              /**  Pointer                            **/
   FieldVal     val;              /**  Value of the radiation             **/
   char         sense[10];        /**  Buffer                             **/
-  char         c;                /**  Individual char                    **/
-  char         d;                /**  Individual char                    **/
   int          count;            /**  Running count                      **/
   int          max_data;         /**  Data limit                         **/
   int          i;                /**  Loop counter                       **/
   bool         done_first_line;  /**  Have we processed the first line?  **/
   bool         end_of_file;      /**  Checks for end of file             **/
-  double       mag;              /**  Magnitude of the current           **/
-  double       phase;            /**  Phase of the current               **/
 
   end_of_file = false;
   fprintf(stdout,"Parsing NEC2 output...\n");
@@ -1011,12 +952,10 @@ void WritePattern(FieldData *field_data, FILE *f) {
 
 void WriteHeader(int xd, int yd, int zd, FILE *f)
 {
-   int i;
    float xo, yo, zo;
    float xs, ys, zs;
    float min[3], max[3];
    unsigned int nv, nc;
-   int v, t;
 
 
    xo = 1.0;
@@ -1055,84 +994,6 @@ void WriteHeader(int xd, int yd, int zd, FILE *f)
 }
 
 
-/*****************************************************************************/
-/*****************************************************************************/
-/**                                                                         **/
-/**                          ParseVolumeData                                **/
-/**                                                                         **/
-/*****************************************************************************/
-/*****************************************************************************/
-
-
-void ParseVolumeData(FILE *fin, 
-                      Ant *currAnt, 
-                     bool  compField, 
-                     bool  compCurrents) {
-
-  char         line[256];        /**  A line in the nec_out file         **/
-  char        *ptr;              /**  Pointer                            **/
-  FieldVal     val;              /**  Value of the radiation             **/
-  char         sense[10];        /**  Buffer                             **/
-  char         c;                /**  Individual char                    **/
-  char         d;                /**  Individual char                    **/
-  int          count;            /**  Running count                      **/
-  int          max_data;         /**  Data limit                         **/
-  int          i;                /**  Loop counter                       **/
-  bool         done_first_line;  /**  Have we processed the first line?  **/
-  bool         end_of_file;      /**  Checks for end of file             **/
-  SegmentData *segptr;           /**  Current data                       **/
-  int          seg_num;          /**  Segment number                     **/
-  int          tag_num;          /**  Wire tag                           **/
-  int          card_num;         /**  Current card number                **/
-  int          dummyi;           /**  Data we don't care about           **/
-  double       dummyf;           /**  Data we don't care about           **/
-  double       mag;              /**  Magnitude of the current           **/
-  double       phase;            /**  Phase of the current               **/
-  FieldData    patterns[10];
-  FILE *outfile;
-  int increment;
-
-  end_of_file = false;
-  fprintf(stdout,"Parsing NEC2 output...\n");
-  if (currAnt->fieldData == NULL)
-    currAnt->fieldData = calloc(1,sizeof(FieldData));
-  max_data = 1024;
-  currAnt->fieldData->count   = 0;
-  currAnt->fieldData->maxgain = 0.0;
-  currAnt->fieldData->mingain = 0.0;
-  currAnt->fieldData->maxtilt = 0.0;
-  currAnt->fieldData->mintilt = 0.0;
-  currAnt->fieldData->vals    = (FieldVal*)malloc(max_data*sizeof(FieldVal));
-  count = 0;
-  done_first_line = false;
-
-
-  if (compField == true) {
-    outfile = fopen("output.raw", "wb");
-    increment = (361 / curr_step_size);
-    /*increment = 71;*/
-    fprintf(stderr, "Increment = %d\n", increment);
-    fprintf(stderr, "CSS = %lf\n", curr_step_size);
-    WriteHeader(increment, increment, FreqSteps, outfile);
-
-    for(i=0; i < FreqSteps;i++) {
-      GetNextPattern(fin, &patterns[i]);
-      WritePattern(&patterns[i], outfile);
-    }
-
-    fclose(outfile);
-
-    system("cont 2 5 0 1 output.raw&");
-
-  }  /**  Compute field  **/
-
-  if (end_of_file == true)
-    printf("NEC RP failed!\n");
-
-}  /**  End of ParseVolumeData  **/
-
-
-
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
